@@ -21,7 +21,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #===============================================================================
 """
-from collections import OrderedDict
+try:
+    from collections import OrderedDict
+except:
+    import OrderedDict
 import logging
 from multiprocessing import Lock
 import sys
